@@ -331,7 +331,7 @@ def extension(string):
         Arguments
         -------------------------
         `value` {str|list}
-            The file extension or list of extensions to format
+            The file extension(s) [separated by commas] or list of extensions to format
 
         Keyword Arguments
         -------------------------
@@ -351,6 +351,9 @@ def extension(string):
         `method_name`: extension
     '''
     new_ext_array = []
+    if isinstance(string,(str)):
+        if "," in string:
+            string = string.split(",")
     if isinstance(string, list) is False:
         string = [string]
 
@@ -360,6 +363,8 @@ def extension(string):
         ext = re.sub(r"^\.*", '', ext)
         new_ext_array.append(ext)
 
+    if len(new_ext_array) > 1:
+        new_ext_array = list(set(new_ext_array))
     if len(new_ext_array) == 1:
         return new_ext_array[0]
     return new_ext_array
